Reproducible research at the GIScience conference
================

This repository is the reproducibility package for the article
*“Reproducible research and GIScience: an evaluation using GIScience
conference papers”*. This repository is based on a previous analysis of
[AGILE conference](https://agile-online.org/conference) submissions, see
<https://github.com/nuest/reproducible-research-and-giscience>
([10.5281/zenodo.1227260](https://doi.org/10.5281/zenodo.1227260)). Find
the preprint and a deposition of this repository via the badges below.

<!--
[![Article DOI](https://img.shields.io/badge/PUBLISHER-https%3A%2F%2Fdoi.org%2FDOI-brightgreen.svg)](https://doi.org/)
-->

[![Earth ArXiv Preprint
DOI](https://img.shields.io/badge/%F0%9F%8C%8D%F0%9F%8C%8F%F0%9F%8C%8E%20EarthArXiv-doi.org%2F10.31223%2FX5ZK5V-%23FF7F2A)](https://doi.org/10.31223/X5ZK5V)
[![Zenodo
DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4032875.svg)](https://doi.org/10.5281/zenodo.4032875)
[![CI rendering of
PDF](https://img.shields.io/badge/PDF-CI%20rendering-informational)](https://nightly.link/nuest/reproducible-research-at-giscience/workflows/pdf/master/reproducible-research-at-giscience.zip)

## Reproduce online

Click the “Binder” button below to open an interactive editing
environment with all required software installed on
[MyBinder.org](https://mybinder.org/). It uses the current version of
the branch `master` in the repository, but you can also enter the Zenodo
DOI (see above) in the MyBinder user interface to open a preserved
release
version.

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/nuest/reproducible-research-at-giscience/master?urlpath=rstudio)

You can start RStudio for the text analysis and figures via “New \>
RStudio” or open the Jupyter Notebook for the bibliographic analysis in
the folder `author_analysis`. You can navigate to the R Markdown
notebook files (see [list of files below](#files-in-this-repository)) to
inspect and execute the code for the text analysis and reproduce the
figures as described in [Reproduce locally](#reproduce-analyses), except
that local installation of required packages is not required.

Use [this
link](https://mybinder.org/v2/zenodo/10.5281/zenodo.4032875/?filepath=author_analysis/BibTex_handling.ipynb)
to directly open the Jupyter Notebook.

Use [this
link](https://mybinder.org/v2/gh/nuest/reproducible-research-at-giscience/master?urlpath=rstudio)
to directly open RStudio.

## Reproduce analyses

Open one of the two *R Markdown analysis files* (`.Rmd`) with
[RStudio](https://www.rstudio.com/products/rstudio/). Then select “Knit
\> Knit to PDF” to render the document. If you have errors rendering the
whole PDF, try running each
[chunk](https://rmarkdown.rstudio.com/authoring_rcodechunks.html) to
locate the problem or use “Knit to HTML”. Depending on the [R Markdown
parameters](https://bookdown.org/yihui/rmarkdown/parameterized-reports.html),
the historic tex analysis tries to download proceedings PDFs from a
private share and requires a login. This download does not work with
knitting the whole document - please execute the chunk
`data_download_drive` manually.

The documents do *not* include code to install required packages. Run
the code in the file `install.R` to install all dependencies. You can
skip the installation of LaTeX (recommended to use
[`tinytex`](https://yihui.org/tinytex/)) and installation of LaTeX
packages if you knit to HTML or run the chunks directly from RStudio.

## Reproduce locally with Docker

Install [Docker CE](https://www.docker.com/community-edition) or a
compatible tool for building an image based on a `Dockerfile` and
running a container based on the image. The `Dockerfile` uses the Rocker
image [`rocker/binder:3.6.3`](https://hub.docker.com/r/rocker/binder),
providing R version `3.6.3` with a CRAN mirror timestamp of July 5th
2019.

Download the project files, open a command line in the root directory
(where this file is), and run the commands as documented at the end of
the `Dockerfile`.

If you have [`repo2docker`](https://repo2docker.readthedocs.io), you can
also run `repo2docker .` and use the `--editable` option to edit the
workflows. *The `repo2docker` option is the only way the original
authors worked on the analysis to ensure the computing environment is
properly managed.* You can most easily achieve it using the included
`Makefile`, just run

``` bash
make
```

## Files in this repository

  - `paper/reproducible-research-at-giscience.Rmd`: The paper
    manuscript; it uses the data from the directories `results` and
    `author_analysis`, which is generated by the other Rmd and Jupyter
    notebooks (see below).
  - `results/paper_assessment.csv`: Results of manual paper evaluation.
  - `results/text_analysis_{topwordstems,keywordstems}.csv`: Results of
    automated text analysis.
  - `results/figure_[...].{pdf,png}`: Figures and plots from text
    analysis and paper assessment; the plots are also created as part of
    the manuscript.
  - `giscience-reproducibility-assessment.Rmd`: R Markdown document with
    the visualisations about the assessment of paper reproducibility.
  - `giscience-historic-text-analysis.Rmd`: R Markdown document with the
    text analysis of historic GIScience proceedings.
  - `Dockerfile`: A recipe for the computational environment using
    [Docker](https://en.wikipedia.org/wiki/Docker_\(software\)).
  - `install.R`: R script file executed during creation of the Docker
    image to install required dependencies.
  - `author_analysis/*`: Data, code, and results simple comparison of
    authors’ last names of the compared conferences based on a Jupyter
    Notebook; the contents of the file `author_counts.csv` are used in
    the article manuscript.

## Deposition on Zenodo

This repository is archived on Zenodo:
**<https://doi.org/10.5281/zenodo.4032875>**

The deposited archive was created using the
[GitHub-Zenodo-integration](https://guides.github.com/activities/citable-code/)
and includes all files.

You can open the Zenodo deposit directly on Binder:
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/zenodo/10.5281/zenodo.4032875/)

## License

The documents in this repository are licensed under a [Creative Commons
Attribution 4.0 International
License](https://creativecommons.org/licenses/by/4.0/).

All contained code is licensed under the [Apache
License 2.0](https://choosealicense.com/licenses/apache-2.0/).

The data used is licensed under a [Open Data Commons Attribution
License](https://opendatacommons.org/licenses/by/).
